@@ -14,5 +14,3 @@ See the License for the specific language governing permissions and
 limitations under the License.
 """
 
-if __name__ == '__main__' :
-    contributions__ = { "Richard Tjörnhammar": "All methods" }
